<template>
    <div class="container">
        <div class="header">
            <div class="title">
                <i class="title-icon"></i>
                <span class="title-text">预算管理统计</span>
            </div>
            <i class="back-icon" @click="handleReset"></i>
        </div>
        <div class="search">
            <el-date-picker
                v-model="year"
                type="year"
                placeholder="请选择年限"
                value-format="yyyy"
                @change="changeYear"
                style="margin-right: 10px"
            >
            </el-date-picker>
            <el-button size="small" @click="findinfo" type="primary">查询</el-button>
            <el-button size="small" @click="reset" type="plain"> 重置 </el-button>
        </div>
        <div class="table">
            <el-table
                :data="tableData"
                stripe
                v-loading="loading"
                @row-click="hanldeRowClick"
                @cell-click="handleCellClick"
                header-cell-class-name="custom-header-cell"
                cell-class-name="custom-cell"
            >
                <el-table-column label="序号" type="index" width="70" align="center">
                </el-table-column>
                <el-table-column align="center" prop="name" label="名称">
                    <template v-slot="{row}">
                        <i class="el-icon-arrow-down" style="margin-right: 10px"></i>
                        {{ row.name }}
                    </template>
                </el-table-column>
                <el-table-column align="center" prop="budgetSum" label="预算总额(万元)">
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.budgetSum) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="alreadyCount"
                    label="计量金额(万元)"
                >
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.alreadyCount) }}
                    </template>
                </el-table-column>
                <el-table-column
                    align="center"
                    prop="distributionCount"
                    label="计量进度(%)"
                >
                    <template v-slot="{row}">
                        {{
                            row.alreadyCount && row.budgetSum
                                ? (row.alreadyCount / row.budgetSum) * 100 == 100
                                    ? (row.alreadyCount / row.budgetSum) * 100 + '%'
                                    : ((row.alreadyCount / row.budgetSum) * 100).toFixed(
                                          2
                                      ) + '%'
                                : '0%'
                        }}
                    </template>
                </el-table-column>
                <el-table-column align="center" prop="totalRate" label="形象进度(万元)">
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.totalRateMoney.toFixed(2)) }}
                    </template>
                </el-table-column>
                <!-- <el-table-column align="center" prop="alreadyCount" label="专项金额">
                    <template v-slot="{row}">
                        {{ utils.thousandBit(row.totalRateMoney.toFixed(2)) }}
                    </template>
                </el-table-column> -->
                <el-table-column align="center" prop="totalRate" label="形象进度(%)">
                    <template v-slot="{row}">
                        {{ utils.thousandBit((row.totalRate * 100).toFixed(2)) + '%' }}
                    </template>
                </el-table-column>

                <el-table-column align="center" prop="ascriptionYear" label="所属年限" />
                <!-- <el-table-column
                    align="center"
                    prop="expectDeviationRate"
                    label="预算偏差"
                >
                    <template v-slot="{row}">
                        {{
                            utils.thousandBit(
                                (row.expectDeviationRate * 100).toFixed(2)
                            ) + '%'
                        }}
                    </template>
                </el-table-column> -->
            </el-table>
            <div class="table-total">
                <span>{{ tableData.length + 1 }}</span>
                <span>总数</span>
                <span class="item">{{ total.budgetSumTotal || 0 }}</span>
                <span class="item">{{ total.alreadyCountTotal || 0 }}</span>
                <span class="item">{{ total.distributionCountTotal || 0 }}</span>
                <span class="item">{{ total.totalRateMoneyTotal || 0 }}</span>
                <span class="item">
                    {{
                        (total.totalRateTotal &&
                            (total.totalRateTotal * 100).toFixed(2) + '%') ||
                        '0%'
                    }}
                </span>
                <span class="item">{{ total.ascriptionYear || 0 }}</span>
                <!-- <span class="item">{{ total.expectDeviationRate || 0 }}</span> -->
            </div>
        </div>
        <div class="charts">
            <div class="charts-border">
                <div class="charts_title">
                    <i class="charts_title-icon"></i>
                    <!-- 养预算金额统计 -->
                    <span class="charts_title-text">预算金额统计</span>
                </div>
                <div id="pie" style="height: 100%; width: 100%"></div>
            </div>
            <div class="charts-border">
                <div class="charts_title">
                    <i class="charts_title-icon clumn-icon"></i>
                    <!-- 预算金额统计 -->
                    <span class="charts_title-text">预算金额统计</span>
                </div>
                <div id="column" style="height: 100%; width: 100%"></div>
            </div>
        </div>
        <div class="charts">
            <div class="charts-border">
                <div class="charts_title" style="left: 60px">
                    <i class="charts_title-icon"></i>
                    <span class="charts_title-text">各部门预算金额使用情况</span>
                </div>
                <div id="column2" style="height: 100%; width: 100%"></div>
            </div>
        </div>
    </div>
</template>

<script>
import utils from '@/utils' // thousandBit格式化千分位
const BigNumber = require('bignumber.js')
import * as echarts from 'echarts'
export default {
    name: 'BugetManagement',
    data() {
        return {
            tableData: [],
            data: [],
            loading: false,
            year: '',
            total: {},
            utils: utils,
        }
    },
    created() {
        this.loadData()
        this.getClumnData2()
        this.$nextTick(() => {
            let date = new Date()
            this.year = date.getFullYear().toString()
        })
    },
    watch: {
        tableData(newVal) {
            this.total.budgetSumTotal = this.calculation('budgetSum', newVal)
            this.total.alreadyCountTotal = this.calculation('alreadyCount', newVal)
            // this.total.totalRateTotal = this.calculation('totalRate', newVal)
            this.total.totalRateMoneyTotal = this.calculation('totalRateMoney', newVal)
            console.log(
                parseFloat(this.total.totalRateMoneyTotal.replace(',', '')) /
                    parseFloat(this.total.budgetSumTotal.replace(',', ''))
            )
            this.total.totalRateTotal =
                parseFloat(this.total.totalRateMoneyTotal.replace(',', '')) /
                parseFloat(this.total.budgetSumTotal.replace(',', ''))

            this.total.distributionCountTotal = this.getDistributionCountTotal(
                this.total.alreadyCountTotal,
                this.total.budgetSumTotal
            )
            // this.total.alreadyCountTotal && this.total.budgetSumTotal
            //   ? (this.total.alreadyCountTotal / this.total.budgetSumTotal) * 100 ==
            //     100
            //     ? (this.total.alreadyCountTotal / this.total.budgetSumTotal) * 100 +
            //       '%'
            //     : (
            //         (this.total.alreadyCountTotal / this.total.budgetSumTotal) *
            //         100
            //       ).toFixed(2) + '%'
            //   : '0.00%'
            this.total.ascriptionYear = newVal.length !== 0 && newVal[0].ascriptionYear
            this.total.expectDeviationRate =
                this.calculation('expectDeviationRate', newVal) * 100 + '%'
            this.cloumnCharts(this.tableData)
            this.pieCharts(this.tableData)
        },
    },
    methods: {
        reset() {
            let date = new Date()
            this.year = date.getFullYear().toString()
            this.loadData()
        },
        getClumnData2() {
            this.$http.get('${yhxt}/yearBudget/v1/getBudgetYearList').then((res) => {
                this.cloumnCharts2(res.data)
            })
        },
        calculation(key, arr) {
            let total = new BigNumber(0)
            if (!key || arr.length === 0) return total.toFixed(2)
            arr.forEach((item) => {
                total = total.plus(item[key])
            })
            if (total === 0) return 0.0
            return utils.thousandBit(total.toFixed(2))
        },
        getDistributionCountTotal(val1, val2) {
            var reg1 = new RegExp(',', 'g')
            val1 = val1.replace(reg1, '')
            val2 = val2.replace(reg1, '')
            val1 = Number(val1)
            val2 = Number(val2)
            console.log(val1)
            let val = new BigNumber(val1)
            if (val1 && val2) {
                return val.div(val2).times(100).toFixed(2) + '%'
                // return val.div(val2).times(100).toFixed(2) + '%'
            } else {
                return '0.00%'
            }
        },
        changeYear(val) {
            if (!val) {
                return this.loadData()
            }
            this.loading = true
            this.$http
                .post('${yhxt}/yearBudget/v1/getBudgetCountVo?year=' + val)
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
        },
        findinfo() {
            this.loading = true
            this.$http
                .post('${yhxt}/yearBudget/v1/getBudgetCountVo?year=' + this.year)
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
        },
        handleReset() {
            let length = this.data.length - 1
            if (length === 0) return
            this.tableData = this.data[this.data.length - 2]
            this.data.splice(length, 1)
        },
        hanldeRowClick(row) {
            if (row.chirldren.length == 0 && row.roadSegmentId) {
                return this.$router.push({
                    name: 'costBudget',
                    params: {
                        value: row,
                    },
                })
            }
            this.tableData = row.chirldren
            this.data.push(row.chirldren)
        },
        handleCellClick(row, column) {
            this.cstatus = column.label
        },
        loadData() {
            this.loading = true
            this.$http
                .post(
                    '${yhxt}/yearBudget/v1/getBudgetCountVo?year=' +
                        new Date().getFullYear()
                )
                .then((res) => {
                    this.tableData = (res && res.status == 200 && res.data) || []
                    this.data = []
                    this.data.push(this.tableData)
                    this.loading = false
                })
                .catch(() => {
                    this.loading = false
                })
        },
        cloumnCharts(data) {
            var chartDom = document.getElementById('column')
            var myChart = echarts.init(chartDom)
            let source = []
            source[0] = ['product', '预算总额', '已用总额']
            data.forEach((item, index) => {
                source[index + 1] = []
                source[index + 1].push(item.name)
                source[index + 1].push(item.budgetSum)
                source[index + 1].push(item.alreadyCount)
            })
            var option
            option = {
                title: {
                    textStyle: {
                        color: '#fff',
                    },
                },
                grid: {
                    top: '20%',
                    left: '10%',
                    right: '10%',
                    bottom: '20%',
                },
                legend: {
                    bottom: 'bottom',
                    bottom: '8%',
                    textStyle: {
                        color: '#fff',
                    },
                },
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'none',
                    },
                },
                color: [
                    '#16ffae',
                    '#00e6f6',
                    '#6255f8',
                    '#0282b9',
                    '#68c1e5',
                    '#578bf1',
                    '#56d0a3',
                    '#596d90',
                    '#6a5cf1',
                ],
                dataset: {source},
                xAxis: {
                    type: 'category',
                    axisLabel: {
                        fontSize: 14,
                        color: '#B8C2CC',
                    },
                    axisTick: {
                        show: true,
                        lineStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisLine: {
                        show: true,
                        lineStyle: {
                            color: '#274561',
                        },
                    },
                },
                yAxis: {
                    name: '单位：万元',
                    nameTextStyle: {
                        color: '#B8C2CC',
                        nameLocation: 'start',
                        fontSize: 18,
                        fontWeight: 700,
                    },
                    type: 'value',
                    splitLine: {show: false}, //去除网格线
                    axisLabel: {
                        textStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisTick: {
                        //y轴刻度线
                        show: true,
                        lineStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisLine: {
                        //y轴
                        show: true,
                        lineStyle: {
                            color: '#274561',
                        },
                    },
                },
                series: [
                    {
                        type: 'bar',
                        barGap: 0,
                        label: {
                            alignTo: 'edge',
                            // formatter: '{name|{b}}{money|{}}\n\n{percent|{c} %}',
                            formatter: (a) => {
                                return `{name|${a.data.name}} {money|${a.data.money} 万元}\n\n{percent|${a.data.value} %}`
                            },
                            minMargin: 5,
                            edgeDistance: 10,
                            lineHeight: 15,
                        },
                        labelLine: {
                            length: 15,
                            length2: 0,
                            maxSurfaceAngle: 80,
                        },
                        labelLayout: function (params) {
                            const isLeft = params.labelRect.x < myChart.getWidth() / 2
                            const points = params.labelLinePoints
                            // Update the end point.
                            points[2][0] = isLeft
                                ? params.labelRect.x
                                : params.labelRect.x + params.labelRect.width
                            return {
                                labelLinePoints: points,
                            }
                        },
                        itemStyle: {
                            color: '#578af0',
                        },
                        barWidth: '15%',
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                    {
                        type: 'bar',
                        barGap: 0,
                        label: {
                            show: false,
                            position: 'top',
                            textStyle: {
                                fontSize: 12,
                                color: '#fff',
                            },
                        },
                        itemStyle: {
                            color: '#56cfa2',
                        },
                        barWidth: '15%',
                        showBackground: true,
                        backgroundStyle: {
                            color: 'rgba(34, 73, 107, 0.5)',
                        },
                    },
                ],
            }

            option && myChart.setOption(option)
        },
        cloumnCharts2(data) {
            data = data || []
            var chartDom = document.getElementById('column2')
            var myChart = echarts.init(chartDom)

            // let dataText = [
            //     '养护预算(四川)',
            //     '专项预算(四川)',
            //     '总预算(四川)',
            //     '养护预算(重庆)',
            //     '专项预算(重庆)',
            //     '总预算(重庆)',
            //     '养护预算(云南)',
            //     '专项预算(云南)',
            //     '总预算(云南)',
            // ]
            // const dataText1 = [
            //     '养护预算(一管理中心)',
            //     '专项预算(一管理中心)',
            //     '总预算(一管理中心)',
            //     '养护预算(二管理中心)',
            //     '专项预算(二管理中心)',
            //     '总预算(二管理中心)',
            //     '养护预算(三管理中心)',
            //     '专项预算(三管理中心)',
            //     '总预算(三管理中心)',
            //     '养护预算(五管理中心)',
            //     '专项预算(五管理中心)',
            //     '总预算(五管理中心)',
            //     '养护预算(四管理中心)',
            //     '专项预算(四管理中心)',
            //     '总预算(四管理中心)',
            // ]

            // 判断是否是渲染下纂数据
            // if(data[0].vos.length === 5) {
            //     dataText = dataText1
            // }
            const xAxisData = [] // x轴
            const xAxisData2 = [] // x轴2
            const customData = [] // 记录滑动模块数据
            const legendData = []
            const dataList = [] // 数据列表
            let dataText = []
            legendData.push('平均值')
            const encodeY = []

            data[0].vos.forEach((i) => {
                dataText.push(i.name)
            })

            for (var i of dataText) {
                legendData.push(i)
                dataList.push([])
                encodeY.push(1 + i)
            }

            data.forEach((i, index) => {
                xAxisData.push(i.year)
                // xAxisData2.push('重庆', '四川', '云南')
                let customVal = [index]
                customData.push(customVal)
                // 获取数组的长度以便赋值数据
                // let num = i.vos.length
                i.vos.forEach((item, index1) => {
                    // let value = {
                    //     value: item.yhBudgetMoney,
                    //     ...item,
                    // }
                    // let value1 = {
                    //     value: item.zxBudgetMoney,
                    //     ...item,
                    // }
                    let value2 = {
                        value: item.budgetMoney,
                        ...item,
                    }
                    // if (index !== 0) {
                    //     index1 = index1 + index * num
                    // }
                    dataList[index1].push(value2)
                    customVal.push(value2.value)
                })
            })
            // console.log(dataList)

            var option
            option = {
                legend: {
                    data: legendData,
                    left: 'center',
                    top: '10%',
                    textStyle: {
                        color: '#fff',
                    },
                },
                dataZoom: [
                    {
                        type: 'slider',
                        start: 0,
                        end: 100,
                        textStyle: {
                            color: '#fff',
                        },
                        bottom: '8%',
                    },
                    {
                        type: 'inside',
                        start: 0,
                        end: 100,
                        textStyle: {
                            color: '#fff',
                        },
                        bottom: '8%',
                    },
                ],
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        type: 'none',
                    },
                },
                toolbox: {
                    show: true,
                    feature: {
                        restore: {show: true},
                    },
                    padding: [60, 60],
                    iconStyle: {
                        borderColor: '#fff',
                    },
                },
                grid: {
                    top: '20%',
                    left: '8%',
                    right: '8%',
                    bottom: '30%',
                    // containLabel: true
                },
                xAxis: [
                    {
                        data: xAxisData,
                        name: '年份',
                        nameTextStyle: {
                            color: '#B8C2CC',
                            nameLocation: 'start',
                            fontSize: 14,
                        },
                        offset: 30,
                        axisLabel: {
                            fontSize: 14,
                            color: '#B8C2CC',
                        },
                        axisTick: {
                            show: true,
                            lineStyle: {
                                color: '#B8C2CC',
                            },
                        },
                        axisLine: {
                            show: true,
                            lineStyle: {
                                color: '#274561',
                            },
                        },
                    },
                    {
                        position: 'bottom',
                        data: xAxisData2,
                        axisLabel: {
                            fontSize: 14,
                            color: '#B8C2CC',
                        },
                        axisTick: {
                            show: true,
                            lineStyle: {
                                color: '#B8C2CC',
                            },
                        },
                        axisLine: {
                            show: true,
                            lineStyle: {
                                color: '#274561',
                            },
                        },
                    },
                ],
                yAxis: {
                    name: '单位：万元',
                    nameTextStyle: {
                        color: '#B8C2CC',
                        nameLocation: 'start',
                        fontSize: 18,
                        fontWeight: 700,
                    },
                    // type: 'value',
                    splitLine: {show: false}, //去除网格线
                    axisLabel: {
                        textStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisTick: {
                        //y轴刻度线
                        show: true,
                        lineStyle: {
                            color: '#B8C2CC',
                        },
                    },
                    axisLine: {
                        //y轴
                        show: true,
                        lineStyle: {
                            color: '#274561',
                        },
                    },
                },
                series: [
                    {
                        type: 'custom',
                        name: '平均值',
                        renderItem: function (params, api) {
                            var xValue = api.value(0)
                            var currentSeriesIndices = api.currentSeriesIndices()
                            var barLayout = api.barLayout({
                                barGap: '30%',
                                barCategoryGap: '20%',
                                count: currentSeriesIndices.length - 1,
                            })
                            var points = []
                            for (var i = 0; i < currentSeriesIndices.length; i++) {
                                var seriesIndex = currentSeriesIndices[i]
                                if (seriesIndex !== params.seriesIndex) {
                                    var point = api.coord([
                                        xValue,
                                        api.value(seriesIndex),
                                    ])
                                    point[0] += barLayout[i - 1].offsetCenter
                                    point[1] -= 20
                                    points.push(point)
                                }
                            }
                            var style = api.style({
                                stroke: api.visual('color'),
                                fill: 'none',
                            })
                            return {
                                type: 'polyline',
                                shape: {
                                    points: points,
                                },
                                style: style,
                            }
                        },
                        itemStyle: {
                            borderWidth: 2,
                        },
                        encode: {
                            x: 0,
                            y: encodeY,
                        },
                        data: customData,
                        z: 100,
                    },
                    ...dataList.map(function (data, index) {
                        return {
                            type: 'bar',
                            animation: false,
                            name: legendData[index + 1],
                            itemStyle: {
                                opacity: 0.9,
                            },
                            data: data,
                            showBackground: true,
                            backgroundStyle: {
                                color: 'rgba(34, 73, 107, 0.5)',
                            },
                        }
                    }),
                ],
            }

            option && myChart.setOption(option)

            myChart.on('click', (event) => {
                // return
                let data = event.data
                // echarts自带加载动画
                myChart.showLoading({
                    color: '#2c5e8e',
                    textColor: '#fff',
                    maskColor: 'rgba(45, 96, 144, 0.6)',
                })
                this.$http
                    .get('${yhxt}/yearBudget/v1/getBudgetYearList?companyId=' + data.id)
                    .then((res) => {
                        myChart.hideLoading() // 关闭动画
                        this.cloumnCharts2(res.data)
                    })
            })
        },
        pieCharts(data) {
            var chartDom = document.getElementById('pie')
            var myChart = echarts.init(chartDom)
            var option
            let data_ = []
            data.forEach((item) => {
                data_.push({
                    value: item.alreadyCount,
                    name: item.name,
                })
            })
            let budget = parseFloat(this.total.budgetSumTotal)
            let already = parseFloat(this.total.alreadyCountTotal)
            budget = new BigNumber(budget)
            data_.push({
                value: budget.minus(already).toFixed(2),
                name: '未用总额',
            })
            // let formatNumber = num =>
            //   num.toString().replace(/(?=(\B)(\d{3})+$)/g, ',')
            option = {
                title: [
                    {
                        text: `{name|预算总额/万元}\n{val|${this.total.alreadyCountTotal}}`,
                        top: 'center',
                        left: 'center',
                        textStyle: {
                            rich: {
                                name: {
                                    fontSize: 14,
                                    color: '#fff',
                                    padding: [10, 0],
                                },
                                val: {
                                    fontSize: 32,
                                    fontWeight: 'bold',
                                    color: '#fff',
                                },
                            },
                        },
                    },
                ],
                tooltip: {
                    trigger: 'item',
                    formatter: (a) => {
                        return `${a.marker} ${a.data.name} ${a.data.value}万元 ${a.percent}%`
                    },
                },
                color: ['#68c1e5', '#578bf1', '#6a5cf1', '#56d0a3', '#596d90'],
                legend: {
                    icon: 'circle',
                    orient: 'vertical',
                    right: 30,
                    top: 'center',
                    bottom: 20,
                    textStyle: {
                        color: '#ccc',
                    },
                },
                series: [
                    {
                        type: 'pie',
                        radius: ['40%', '55%'],
                        // center: ['45%', '50%'],
                        data: data_,
                        label: {
                            alignTo: 'edge',
                            formatter: (a) => {
                                return `{percent|${a.percent}%}`
                            },
                            minMargin: 5,
                            edgeDistance: '15%',
                            rich: {
                                percent: {
                                    fontSize: 15,
                                    color: '#fff',
                                },
                            },
                        },
                    },
                ],
            }

            option && myChart.setOption(option)
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/ .el-date-editor {
    background-color: #103c5d;
    border: none;
}
/deep/ .el-range-separator {
    color: #fff;
}
/deep/ .el-table th.is-leaf {
    background-color: transparent !important;
}
/deep/ .el-table__row {
    background-color: #0b426e !important;
}
/deep/ .el-table__row--striped {
    background-color: #124873 !important;
}
/deep/ .el-table__header-wrapper {
    border-top-left-radius: 10px;
    border-top-right-radius: 10px;
}
/deep/ .el-table__body-wrapper {
    border-bottom-left-radius: 10px;
    border-bottom-right-radius: 10px;
}
/deep/ .el-table {
    background-color: transparent;
}
.container {
    padding: 30px;
    overflow: auto;
    box-sizing: border-box;

    .header {
        height: 59px;
        width: 100%;
        display: flex;
        justify-content: space-between;
        border-bottom: 1px solid #4d7faf;
        .title {
            display: flex;
            height: 34px;
            align-items: center;
            .title-icon {
                display: block;
                width: 28px;
                height: 28px;
                background-image: url('../../assets/img/icon-标题@2x.png');
                background-size: 100% 100%;
            }
            .title-text {
                margin-left: 5px;
                height: 34px;
                font-size: 26px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                line-height: 34px;
                color: transparent;
                -webkit-background-clip: text;
                background-image: linear-gradient(180deg, #e5f2ff 24%, #1f5c99 100%);
            }
        }
        .back-icon {
            margin-right: 10px;
            cursor: pointer;
            display: block;
            width: 40px;
            height: 40px;
            background-size: 100% 100%;
            background-image: url(../../assets//img/icon-返回@2x.png);
        }
    }
    .search {
        margin-top: 32px;
    }
    .table {
        margin-top: 12px;
        width: 100%;
        /deep/ .custom-header-cell {
            background-color: #145080 !important;
            padding: 15px 0;
            .cell {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
            }
        }
        /deep/ .custom-cell {
            padding: 15px 0;
            cursor: pointer;
            .cell,
            div {
                font-size: 16px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 400;
                color: #e5f2ff;
            }
        }
        .table-total {
            display: flex;
            justify-content: center;
            align-items: center;
            height: 64px;
            background-color: #145080;
            border-radius: 10px;
            margin-top: 8px;
            span {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
                text-align: center;
                &:nth-child(1) {
                    width: 70px;
                }
                &:not(:nth-child(1)) {
                    flex: 1;
                }
            }
        }
    }
    .charts {
        margin-top: 32px;
        display: flex;
        .charts-border {
            position: relative;
            height: 507px;
            flex: 1;
            background-size: 100% 100%;
            background-image: url('../../assets/img/框@2x.png');
            .charts_title {
                display: flex;
                height: 24px;
                align-items: center;
                position: absolute;
                top: 30px;
                left: 25px;
            }
            .charts_title-icon {
                display: block;
                width: 20px;
                height: 20px;
                background-size: 100% 100%;
                background-image: url('../../assets/img/icon-饼图@2x.png');
            }
            .clumn-icon {
                background-image: url('../../assets/img/icon-柱图@2x.png');
            }
            .charts_title-text {
                margin-left: 5px;
                height: 24px;
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                line-height: 24px;
                color: transparent;
                -webkit-background-clip: text;
                background-image: linear-gradient(180deg, #e5f2ff 24%, #1f5c99 100%);
            }
        }
    }
}
</style>
